==> provider_software_3.7.4.tar.gz: provider_software_3.7.4/tools/fixpermissions.py <==
#!C:\Programme\Python27\python.exe

import sys, os


def updateShebang(fn):
    f = file(fn, 'r')
    text = f.readline()
    if text[:2] == "#!":
        text = "#!%s\n" % (sys.executable)
    text += f.read()
    # text = text.replace(chr(13), '')
    f.close()
    # write back
    fw = file(fn, 'w')
    fw.write(text)
    fw.close()


# MAIN
# print '+++  Adapt file permissions and shebangs. chmod, change shebang to %s.' % (sys.executable)

scriptDirs = ['../www/', '.']
suffices = ['.cgi', '.py']
writeDirs = ['../config/', '../log/', '../cache/', '../archive/', '../www/downloads/']
writeExecDirs = ['../www/configtool/']
errors = 0


def chmod(f, mode):
    try:
        os.chmod(f, mode)
        return 0
    except Exception, e:
        print "    ERROR: %s." % e
        return 1

for d in writeDirs:
    d = os.path.abspath(d)
    print "  Setting write permissions for all users in directory %s" % d
    for root, dirs, files in os.walk(d):
        for name in files:
            f = os.path.join(root, name)
            # print "  update %s" % f
            errors += chmod(f, 0666)
        # print "  -- update directories --"
        for name in dirs:
            f = os.path.join(root, name)
            # print "  update %s" % f
            errors += chmod(f, 0777)
        # print "  update %s" % root
        errors += chmod(root, 0777)

for d in writeExecDirs:
    d = os.path.abspath(d)
    print "  Setting execution & write permission for all users in directory %s" % d
    for root, dirs, files in os.walk(d):
        for name in files:
            for suff in suffices:
                if name[-len(suff):] == suff:
                    f = os.path.join(root, name)
                    # print "  update %s" % f
                    errors += chmod(f, 0777)
        for name in dirs:
            f = os.path.join(root, name)
            # print "  update %s" % f
            errors += chmod(f, 0777)
        # print "  update %s" % root
        errors += chmod(root, 0777)

for d in scriptDirs:
    d = os.path.abspath(d)
    print "  Updating scripts in directory %s" % d
    for root, dirs, files in os.walk(d):
        for name in files:
            for suff in suffices:
                if name[-len(suff):] == suff:
                    # change this script
                    f = os.path.join(root, name)
                    # print "  update %s" % f
                    errors += chmod(f, 0755)
                    try:
                        updateShebang(f)
                    except Exception, e:
                        print "    ERROR: %s." % e
                        errors += 1

print
if errors:
    print '#' * 105
    print "IMPORTANT: Please note the error messages above and resolve these issues.\nThen re-run the script fixpermissions.py in the tools folder manually before proceeding to use BioCASe."

==> provider_software_3.8.4.tar.gz: provider_software_3.8.4/tools/fixpermissions.py <==
#!c:\Program Files\Python39\python.exe

import sys, os


def updateShebang(fn):
    f = open(fn, 'r')
    text = f.readline()
    if text[:2] == "#!":
        text = "#!%s\n" % (sys.executable)
    text += f.read()
    # text = text.replace(chr(13), '')
    f.close()
    # write back
    fw = open(fn, 'w')
    fw.write(text)
    fw.close()


# MAIN
# print '+++  Adapt file permissions and shebangs. chmod, change shebang to %s.' % (sys.executable)

scriptDirs = ['../www/', '.']
suffices = ['.cgi', '.py']
writeDirs = ['../config/', '../log/', '../cache/', '../archive/', '../www/downloads/']
writeExecDirs = ['../www/configtool/']
errors = 0


def chmod(f, mode):
    try:
        os.chmod(f, mode)
        return 0
    except Exception as e:
        print("    ERROR: %s." % e)
        return 1

for d in writeDirs:
    d = os.path.abspath(d)
    print("  Setting write permissions for all users in directory %s" % d)
    for root, dirs, files in os.walk(d):
        for name in files:
            f = os.path.join(root, name)
            # print "  update %s" % f
            errors += chmod(f, 0o666)
        # print "  -- update directories --"
        for name in dirs:
            f = os.path.join(root, name)
            # print "  update %s" % f
            errors += chmod(f, 0o777)
        # print "  update %s" % root
        errors += chmod(root, 0o777)

for d in writeExecDirs:
    d = os.path.abspath(d)
    print("  Setting execution & write permission for all users in directory %s" % d)
    for root, dirs, files in os.walk(d):
        for name in files:
            for suff in suffices:
                if name[-len(suff):] == suff:
                    f = os.path.join(root, name)
                    # print "  update %s" % f
                    errors += chmod(f, 0o777)
        for name in dirs:
            f = os.path.join(root, name)
            # print "  update %s" % f
            errors += chmod(f, 0o777)
        # print "  update %s" % root
        errors += chmod(root, 0o777)

for d in scriptDirs:
    d = os.path.abspath(d)
    print("  Updating scripts in directory %s" % d)
    for root, dirs, files in os.walk(d):
        for name in files:
            for suff in suffices:
                if name[-len(suff):] == suff:
                    # change this script
                    f = os.path.join(root, name)
                    # print "  update %s" % f
                    errors += chmod(f, 0o755)
                    try:
                        updateShebang(f)
                    except Exception as e:
                        print("    ERROR: %s." % e)
                        errors += 1

print()
if errors:
    print('#' * 105)
    print("IMPORTANT: Please note the error messages above and resolve these issues.\nThen re-run the script fixpermissions.py in the tools folder manually before proceeding to use BioCASe.")
